@@ -82,7 +82,7 @@ typedef enum {
 
 void NYTProf_croak_if_not_stdio(NYTP_file file, const char *function);
 
-size_t NYTP_write_header(NYTP_file ofile, unsigned int major, unsigned int minor);
+size_t NYTP_write_header(NYTP_file ofile, U32 major, U32 minor);
 size_t NYTP_write_comment(NYTP_file ofile, const char *format, ...);
 size_t NYTP_write_attribute_string(NYTP_file ofile,
                                    const char *key, size_t key_len,
@@ -92,30 +92,31 @@ size_t NYTP_write_attribute_signed(NYTP_file ofile, const char *key,
 size_t NYTP_write_attribute_unsigned(NYTP_file ofile, const char *key,
                                      size_t key_len, unsigned long value);
 size_t NYTP_start_deflate_write_tag_comment(NYTP_file ofile, int compression_level);
-size_t NYTP_write_process_start(NYTP_file ofile, unsigned int pid,
-                                unsigned int ppid, NV time_of_day);
-size_t NYTP_write_process_end(NYTP_file ofile, unsigned int pid,
-                              NV time_of_day);
-size_t NYTP_write_sawampersand(NYTP_file ofile, unsigned int fid, unsigned int line);
-size_t NYTP_write_new_fid(NYTP_file ofile, unsigned int id,
-                          unsigned int eval_fid, unsigned int eval_line_num,
-                          unsigned int flags, unsigned int size,
-                          unsigned int mtime, const char *name, I32 len);
-size_t NYTP_write_time_block(NYTP_file ofile, unsigned int elapsed,
-                             unsigned int fid, unsigned int line,
-                             unsigned int last_block_line,
-                             unsigned int last_sub_line);
-size_t NYTP_write_time_line(NYTP_file ofile, unsigned int elapsed,
-                            unsigned int fid, unsigned int line);
-size_t NYTP_write_sub_info(NYTP_file ofile, unsigned int fid,
-                           const char *name, I32 len,
-                           unsigned int first_line, unsigned int last_line);
-size_t NYTP_write_sub_callers(NYTP_file ofile, unsigned int fid,
-                              unsigned int line,
-                              const char *caller_name, I32 caller_name_len,
-                              unsigned int count, NV incl_rtime, NV excl_rtime,
-                              NV reci_rtime, unsigned int depth,
-                              const char *called_name, I32 called_name_len);
-size_t NYTP_write_src_line(NYTP_file ofile, unsigned int fid,
-                           unsigned int line, const char *text, I32 text_len);
+size_t NYTP_write_process_start(NYTP_file ofile, U32 pid, U32 ppid, NV time_of_day);
+size_t NYTP_write_process_end(NYTP_file ofile, U32 pid, NV time_of_day);
+size_t NYTP_write_sawampersand(NYTP_file ofile, U32 fid, U32 line);
+size_t NYTP_write_new_fid(NYTP_file ofile, U32 id, U32 eval_fid, U32 eval_line_num,
+                        U32 flags, U32 size, U32 mtime, const char *name, I32 len);
+size_t NYTP_write_time_block(NYTP_file ofile, I32 elapsed, U32 overflow,
+                        U32 fid, U32 line, U32 last_block_line, U32 last_sub_line);
+size_t NYTP_write_time_line(NYTP_file ofile, I32 elapsed, U32 overflow,
+                        U32 fid, U32 line);
+size_t NYTP_write_sub_info(NYTP_file ofile, U32 fid, const char *name, I32 len,
+                        U32 first_line, U32 last_line);
+size_t NYTP_write_sub_callers(NYTP_file ofile, U32 fid, U32 line,
+                        const char *caller_name, I32 caller_name_len,
+                        U32 count, NV incl_rtime, NV excl_rtime,
+                        NV reci_rtime, U32 depth,
+                        const char *called_name, I32 called_name_len);
+size_t NYTP_write_src_line(NYTP_file ofile, U32 fid,
+                        U32 line, const char *text, I32 text_len);
 size_t NYTP_write_discount(NYTP_file ofile);
+
+
+/* XXX
+ * On the write-side the functions above encapsulate the data format.
+ * On the read-side we've not got that far yet (and there's less need).
+ */
+U32 read_u32(NYTP_file ifile);
+NV  read_nv(NYTP_file ifile);
+
